@@ -2,23 +2,17 @@
     LessCss tests
 """
 import unittest
-import sys, os
+import os
 import re
 
-here = os.path.dirname(__file__)
-path = os.path.abspath(here)
-while os.path.dirname(path) != path:
-    if os.path.exists(os.path.join(path, 'lesscpy', '__init__.py')):
-        sys.path.insert(0, path)
-        break
-    path = os.path.dirname(path)
+import bootstrap
 
 def find():
     svn = re.compile('\.svn')
     test = re.compile('test.+\.py$')
     skip = re.compile('testissues.*')
     alltests = unittest.TestSuite()
-    for path, dirs, files in os.walk(here):
+    for path, _, files in os.walk(bootstrap.here):
         if svn.search(path):
             continue
         for f in files:
@@ -30,4 +24,5 @@ def find():
     return alltests
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='find')
\ No newline at end of file
+    unittest.main(defaultTest='find')
+    
\ No newline at end of file
