@@ -4,11 +4,11 @@
 import unittest
 import os
 import glob
-import sys
-import filecmp
-sys.path.append('..')
-from lessc import parser
-from lessc import formatter
+import bootstrap
+
+from lesscpy.lessc import parser
+from lesscpy.lessc import formatter
+
 
 class TestCase(unittest.TestCase):
     pass
